nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Sum

Struct Sum 

#[repr(transparent)]
pub struct Sum(pub u32);
CRC checksum register

Tuple Fields

0: u32

Implementations

Source

impl Sum

pub const fn crc_sum(&self) -> u32

The most recent CRC sum can be read through this register with selected bit order and 1’s complement post-processes.

pub const fn set_crc_sum(&mut self, val: u32)

The most recent CRC sum can be read through this register with selected bit order and 1’s complement post-processes.