#[repr(transparent)]pub struct WrData(pub u32);Expand description
CRC data register
Tuple Fields
0: u32Implementations
Sourceimpl WrData
impl WrData
Sourcepub const fn crc_wr_data(&self) -> u32
pub const fn crc_wr_data(&self) -> u32
Data written to this register will be taken to perform CRC calculation with selected bit order and 1’s complement pre-process. Any write size 8, 16 or 32-bit are allowed and accept back-to-back transactions.
Sourcepub const fn set_crc_wr_data(&mut self, val: u32)
pub const fn set_crc_wr_data(&mut self, val: u32)
Data written to this register will be taken to perform CRC calculation with selected bit order and 1’s complement pre-process. Any write size 8, 16 or 32-bit are allowed and accept back-to-back transactions.