#[repr(transparent)]pub struct Sum(pub u32);Expand description
CRC checksum register
Tuple Fields
0: u32Implementations
Sourceimpl Sum
impl Sum
Sourcepub const fn crc_sum(&self) -> u32
pub const fn crc_sum(&self) -> u32
The most recent CRC sum can be read through this register with selected bit order and 1’s complement post-processes.
Sourcepub const fn set_crc_sum(&mut self, val: u32)
pub const fn set_crc_sum(&mut self, val: u32)
The most recent CRC sum can be read through this register with selected bit order and 1’s complement post-processes.